function VCO_seismogram(metadata,time, data,wavfile) 
%
% Function to create Amplitude/Frequency Modulation sound file of a seismogram
% Originally created by David Simpson, December 2009
% Modified by Zhigang Peng, 2012
% Modified by Debi Kilb, May 2012
% test scale = 1; speed_factor = 100; vcof = 100; sacfile = 'BK.PKD.HHT.SAC'; 
%

%
%  Define static parameters
%
vcof = 100; % parameter used to smooth envelope
time =  time;
speed_factor = metadata.speed_factor;
datavals = data.data;
delta = 1./data.sampleRate; 
Nf = 1/(2*delta);
filt_low_sound_vco = metadata.filt_low_sound_vco;
filt_high_sound_vco = metadata.filt_high_sound_vco;
%
%  Make sure frequencies are below Nyquest
if filt_high_sound_vco>=Nf
   filt_high_sound_vco = Nf*0.99;
end
nsamp = data.sampleRate;  % sampling rate
datavals = datavals - mean(datavals); % remean
max_datavals = max(abs(datavals));
datavals = datavals./max_datavals; % normalize by the maximum amplitude
%
% Now enter VCO mode 
%
%  A few notes by Debi about fmid: 100 is to low, 200 works well, 5000 is too high, 
%     800 sounds like 200 to me
%
%fmin=600; % not used
%fmax=3600; % not used
fmin=8000; % not used
fmax=10000; % not used
%disp('Not sure what fmid should be ....')
fmid = 800; 
%fmid = 7500; % 7500/750 = 10
%fmid = 12000; % 12000/750 = 16
%fmid = 1500; % maybe this for 750 speed up?? 2 Hz --> (1500/750 = 2; 1500 is what is heard, 750 speed factor, 2 Hz actual)  Go back to 800 if does not work
%fmid = 200; % maybe this for 750 speed up??  Go back to 800 if does not work
%
% Option to resample to get a higher resolution modulating signal.
% Modulating signal length and wavwrite frequency determine final signal length
% Best to use lower resample freq and higher wavwrite freq
%    yy=resample(datavals,vcof,nsamp);
% no need to do the resampling here
%
   yy = datavals;
   yy_filt = eqfiltfilt(double(yy),filt_low_sound_vco,filt_high_sound_vco,delta,4);
   yy_filt = eqfiltfilt(double(yy),filt_low_sound_vco,filt_high_sound_vco,delta,4);
%
%     zz = vco(0.8*(yy),[fmin fmax],20000);
%   zz is the frequency modulated signal
%   (multiply by 0.8 to avoid error in the Matlab vco subroutine)
%    zz = vco(0.8*(yy),[fmin fmax],20000);
%    zz = vco(0.8*(yy),fmid,20000);
    zz = vco(yy,fmid,20000); % normalized above, no need for scaling
%
% Create envelope function of the waveform using the hilbert transform
%disp('update this ....')
% control the volume of the sound file
%  multiply the frequcny modulated signal by the envelope to get the
%  amplitude and frequency modulated sound
%
    %ayy=0.005+0.9*(smooth_envelope(yy,10*vcof));
    %ayy_filt=0.005+0.9*(smooth_envelope(yy_filt,10*vcof));
    smooth_ev = smooth_envelope(yy,10*vcof);
    smooth_ev_filt = smooth_envelope(yy_filt,10*vcof);
    smooth_ev = smooth_ev./max(abs(smooth_ev)); % normalize
    smooth_ev_filt = smooth_ev_filt./max(abs(smooth_ev_filt)); % normalize
    smooth_combine = smooth_ev + smooth_ev_filt;
    smooth_combine = smooth_combine./(max(abs(smooth_ev_filt))); % normalize
    ayy=0.005+0.7*smooth_combine;
    yyy = (ayy).*(zz);
    ifplot = 1;
    if (ifplot),
       figure(10)
       clf
       subplot(3,1,1);
       plot(yy);
       axis tight
       title('Original seismogram')
       subplot(3,1,2);
       plot(ayy);
       axis tight
       title('Smoothed envelope, used as sound volume')
       subplot(3,1,3);
       plot(yyy);
       axis tight
       title('Amplitude and frequency modulated signal')
    end;
%
%    soundsc(yyy,8000);
%     wavwrite(yyy,8000,'movie_vco_hf_3');
% debi commented out FS = floor(vcof*speed_factor);
  FS = floor(nsamp*speed_factor); % Debi added to be consistent w/movie
  NBITS = 16;
%
% Create the stereo pair by putting the original and the freq. modulated data together
% out = [yy yyy];
% apply a filter to remove the long-period signals
%
  ch1 = metadata.filt_low_sound;
  ch2 = metadata.filt_high_sound;
  %yy1=eqfiltfilt(yy,ch1,ch2,delta,4);
  yy1=eqfiltfilt(double(yy),ch1,ch2,delta,4);
  max_yy1 = max(abs(yy1));
  %yy1 = yy1./max_yy1.*scale;
  yy1 = yy1./max_yy1;
% scale the high-freq. output accordly.

%out = [yy1 yyy./8]; % divide the VCO signal by third to make them sounds smaller
%out = [yy1 yyy./6]; % divide the VCO signal by third to make them sounds smaller
out = [yy1 yyy./8]; % divide the VCO signal by third to make them sounds smaller
%out = [yy1./8 yyy]; % divide the VCO signal by third to make them sounds smaller
%
%   It is important to normalize the data to be <1 and >-1:
%        data_wave_norm = data_wav/max(abs(data_wav)*1.0001);
%   before calling the MATLAB wavwrite program to avoid warnings
%   about data clipping of the form ‘Warning: data clipped during
%   write to file’.

maxout = max(max(abs(out)));
out = out/(maxout*1.0001);

if metadata.iflag_stereo
    out_temp = (out(:,1)+out(:,2))./2;
    out_temp = out_temp./(max(abs(out_temp))*1.0001);
    out_combine(:,1) = out_temp;
    out_combine(:,2) = out_temp;
    wavwrite(out_combine,FS,NBITS,wavfile);
else
   wavwrite(out,FS,NBITS,wavfile);
end
